"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var globalStore_1 = require("../constants/globalStore");
var flush_store_1 = require("../utils/flush-store");
var get_country_data_1 = require("../utils/get-country-data");
var get_country_url_1 = require("../utils/get-country-url");
var get_images_1 = require("../utils/get-images");
var save_files_1 = require("../utils/save-files");
var createCountriesPromises = function () {
    var countryDataPromises = [];
    var countries = globalStore_1.store.countriesInList.slice();
    countries.forEach(function (country) {
        var url = get_country_url_1.getCountryURL(country.isoCode);
        countryDataPromises.push(get_country_data_1.getCountryData(country, url));
    });
    return countryDataPromises;
};
function getCountriesData() {
    globalStore_1.store.countriesInList.sort();
    var promises = createCountriesPromises();
    Promise.all(promises)
        .then(function () {
        if (globalStore_1.store.failedCountries.length) {
            globalStore_1.store.countriesInList = globalStore_1.store.failedCountries.slice();
            globalStore_1.store.failedCountries.length = 0;
            setTimeout(function () {
                globalStore_1.store.debugLogger('Waiting 3 seconds before retrieving missed countries...');
                getCountriesData();
            }, 3000);
        }
        else {
            save_files_1.saveFiles();
            get_images_1.getImages();
            flush_store_1.flushStore();
        }
    })
        .catch(function (err) {
        globalStore_1.store.errorLogger(new Date().toISOString() + '\n\n' + err.toString() + '\n\n');
    });
}
exports.getCountriesData = getCountriesData;
